@@ -8,6 +8,12 @@ import PIL
 from PIL import Image
 from PIL import ImageDraw
 
+try:
+    import cv2
+    _cv2_available = True
+except ImportError:
+    _cv2_available = False
+
 
 def format_mat(x, precision):
     return ("[%s]" % (
@@ -965,7 +971,8 @@ class PinholeCameraModel(object):
         else:
             return img[y1:y2, x1:x2]
 
-    def crop_resize_image(self, img, interpolation=PIL.Image.BILINEAR):
+    def crop_resize_image(self, img, interpolation=PIL.Image.BILINEAR,
+                          use_cv2=True):
         """Crop and resize input full resolution image.
 
         Parameters
@@ -986,12 +993,14 @@ class PinholeCameraModel(object):
         if self._target_size is None:
             raise ValueError('Target size is not specified')
 
-        out_shape = self._target_size
+        H, W = img.shape[:2]
+        out_W, out_H = self._target_size
+        out_shape = (out_H, out_W)
         if img.ndim == 3:
-            H, W, C = img.shape
-            out_shape += (C, )
+            _, _, C = img.shape
+            out_shape += (C,)
         elif img.ndim == 2:
-            H, W = img.shape
+            pass
         else:
             raise ValueError('Input image is not gray or rgb image.')
         if H != self._full_height or W != self._full_width:
@@ -1001,10 +1010,71 @@ class PinholeCameraModel(object):
 
         cropped_img = img[y1:y2, x1:x2]
         out = np.empty(out_shape, dtype=img.dtype)
-        pil_img = Image.fromarray(cropped_img)
-        out[:] = pil_img.resize(self._target_size, resample=interpolation)
+        if use_cv2 and _cv2_available:
+            if interpolation == PIL.Image.NEAREST:
+                cv_interpolation = cv2.INTER_NEAREST
+            elif interpolation == PIL.Image.BILINEAR:
+                cv_interpolation = cv2.INTER_LINEAR
+            elif interpolation == PIL.Image.BICUBIC:
+                cv_interpolation = cv2.INTER_CUBIC
+            elif interpolation == PIL.Image.LANCZOS:
+                cv_interpolation = cv2.INTER_LANCZOS4
+            out[:] = cv2.resize(cropped_img, self._target_size,
+                                interpolation=cv_interpolation)
+        else:
+            pil_img = Image.fromarray(cropped_img)
+            out[:] = pil_img.resize(self._target_size, resample=interpolation)
         return out
 
+    def resize_bbox(self, bbox):
+        """Resize input full resolution bbox.
+
+        Parameters
+        ----------
+        bbox : numpy.ndarray or list[float]
+            input bbox. Input shape can be (4,) or (N, 4).
+            [top, left, bottom, right] order.
+
+        Returns
+        -------
+        out_bbox : numpy.ndarray
+            resized bbox.
+        """
+        bbox = np.array(bbox, 'f')
+        resize_scales = np.array([self._binning_y, self._binning_x,
+                                  self._binning_y, self._binning_x], 'f')
+        if bbox.ndim == 1:
+            out_bbox = bbox / resize_scales
+        elif bbox.ndim == 2:
+            out_bbox = bbox / resize_scales.reshape(1, 4)
+        else:
+            raise ValueError("Not valid bboxes")
+        return out_bbox
+
+    def resize_point(self, uv_point):
+        """Resize input full resolution uv point.
+
+        Parameters
+        ----------
+        uv_point : numpy.ndarray or list[float]
+            input point. Input shape can be (2,) or (N, 2).
+            [u, v] order.
+
+        Returns
+        -------
+        out_point : numpy.ndarray
+            resized point.
+        """
+        uv_point = np.array(uv_point, 'f')
+        resize_scales = np.array([self._binning_x, self._binning_y], 'f')
+        if uv_point.ndim == 1:
+            out_point = uv_point / resize_scales
+        elif uv_point.ndim == 2:
+            out_point = uv_point / resize_scales.reshape(1, 2)
+        else:
+            raise ValueError("Not valid points")
+        return out_point
+
     def project_pixel_to_3d_ray(self, uv, normalize=False):
         """Returns the ray vector
 
@@ -1352,3 +1422,26 @@ class PinholeCameraModel(object):
             np_pil_img = np.array(pil_img, dtype=img.dtype)
             bgr_img[:] = np_pil_img[..., rgb_to_bgr_indices]
             return bgr_img
+
+    def points_in_roi(self, points):
+        """Check if input points are in roi.
+
+        Parameters
+        ----------
+        points : list[list[float, float]]
+            [[x_1, y_1], [x_2, y_2] ..., [x_n, y_n]].
+
+        Returns
+        -------
+        result list[bool]
+            True if the point is in roi, False otherwise.
+        """
+        result = []
+        for point in points:
+            if self.roi[1] <= point[0] <= self.roi[3] \
+               and self.roi[0] <= point[1] <= self.roi[2]:
+                result.append(True)
+            else:
+                result.append(False)
+
+        return result
