@@ -36,10 +36,10 @@ class TestPinholeCameraModel(unittest.TestCase):
 
     def test_crop_image(self):
         cropped_cm = copy.deepcopy(self.cm)
-        cropped_cm.roi = [0, 0, 100, 100]
+        cropped_cm.roi = [0, 0, 100, 101]
         img = np.zeros((480, 640))
         ret_img = cropped_cm.crop_image(img)
-        testing.assert_equal(ret_img.shape, (100, 100))
+        testing.assert_equal(ret_img.shape, (100, 101))
 
         with self.assertRaises(ValueError):
             cropped_cm.crop_image(np.zeros(100))
@@ -48,24 +48,57 @@ class TestPinholeCameraModel(unittest.TestCase):
             cropped_cm.crop_image(np.zeros((100, 100)))
 
     def test_crop_resize_image(self):
-        cropped_cm = copy.deepcopy(self.cm)
-        cropped_cm.roi = [0, 0, 100, 100]
-        gray_img = np.zeros((480, 640), dtype=np.uint8)
-        cropped_cm.target_size = (256, 256)
-        ret_img = cropped_cm.crop_resize_image(gray_img)
-        testing.assert_equal(ret_img.shape, (256, 256))
+        for use_cv2 in [False, True]:
+            cropped_cm = copy.deepcopy(self.cm)
+            cropped_cm.roi = [0, 0, 100, 100]
+            gray_img = np.zeros((480, 640), dtype=np.uint8)
+            cropped_cm.target_size = (256, 257)
+            ret_img = cropped_cm.crop_resize_image(gray_img,
+                                                   use_cv2=use_cv2)
+            testing.assert_equal(ret_img.shape, (257, 256))
 
-        bgr_img = np.zeros((480, 640, 3), dtype=np.uint8)
-        cropped_cm.target_size = (10, 10)
-        ret_img = cropped_cm.crop_resize_image(bgr_img)
-        testing.assert_equal(ret_img.shape, (10, 10, 3))
+            bgr_img = np.zeros((480, 640, 3), dtype=np.uint8)
+            cropped_cm.target_size = (11, 10)
+            ret_img = cropped_cm.crop_resize_image(bgr_img,
+                                                   use_cv2=use_cv2)
+            testing.assert_equal(ret_img.shape, (10, 11, 3))
 
-        with self.assertRaises(ValueError):
-            cropped_cm.crop_resize_image(np.zeros(100))
+            with self.assertRaises(ValueError):
+                cropped_cm.crop_resize_image(np.zeros(100),
+                                             use_cv2=use_cv2)
 
-        with self.assertRaises(ValueError):
-            cropped_cm.crop_resize_image(
-                np.zeros((100, 100), dtype=np.uint8))
+            with self.assertRaises(ValueError):
+                cropped_cm.crop_resize_image(
+                    np.zeros((100, 100), dtype=np.uint8),
+                    use_cv2=use_cv2)
+
+    def test_resize_bbox(self):
+        resized_cm = self.cm.crop_resize_camera_info(
+            target_size=[100, 200])
+        out_bbox = resized_cm.resize_bbox(
+            [[0, 0, self.cm.height, self.cm.width]])
+        testing.assert_almost_equal(
+            out_bbox, [[0, 0, 200, 100]], decimal=4)
+
+        out_bbox = resized_cm.resize_bbox(
+            [0, 0, self.cm.height, self.cm.width])
+        testing.assert_almost_equal(
+            out_bbox, [0, 0, 200, 100], decimal=4)
+
+    def test_resize_point(self):
+        resized_cm = self.cm.crop_resize_camera_info(
+            target_size=[100, 200])
+        out_point = resized_cm.resize_point(
+            [[0, 0],
+             [0, self.cm.height],
+             [self.cm.width, self.cm.height],
+             [self.cm.width, 0]])
+        testing.assert_almost_equal(
+            out_point,
+            [[0, 0],
+             [0, 200],
+             [100, 200],
+             [100, 0]], decimal=4)
 
     def test_calc_f_from_fov(self):
         f = PinholeCameraModel.calc_f_from_fov(90, 480)
@@ -144,6 +177,19 @@ class TestPinholeCameraModel(unittest.TestCase):
         cm.draw_roi(alpha_img, copy=True)
         testing.assert_equal(alpha_img, alpha_img_org)
 
+    def test_points_roi(self):
+        cm = PinholeCameraModel.from_yaml_file(kinect_v2_camera_info())
+        points = [[874.5, 680],
+                  [875, 680],
+                  [875, 679.5],
+                  [1072, 680],
+                  [1072.5, 680],
+                  [1072, 859],
+                  [1072, 869.5]]
+        testing.assert_equal(
+            cm.points_in_roi(points),
+            [False, True, False, True, False, True, False])
+
     def test__target_size(self):
         cm = PinholeCameraModel.from_yaml_file(kinect_v2_camera_info())
         cm.target_size = (640, 480)
